"""Module doc string."""
# pylint: disable=locally-disabled


# pylint: disable=too-few-public-methods
class Base:
    """My base class."""


# pylint: enable=too-few-public-methods


class BaseCorrect:  # pylint: disable=too-few-public-methods
    """My base class."""


class BaseInner:
    # pylint: disable=too-few-public-methods
    """My base class."""
