class Point:
    def __init__(self, x, y):
        """Represents a point in the xy-coordinate plane.

        :param x: x coordinate
        :param y: y coordinate
        """
        self.x = x
        self.y = y
