# pylint: disable=missing-docstring,unused-import
# https://github.com/pylint-dev/pylint/issues/3595

import collections

class Example:
    def __init__(self):
        self.prev()
        self.next()
    def prev(self):
        pass
    def next(self):
        pass
