# pylint: disable=trailing-whitespace, missing-module-docstring, trailing-newlines, missing-final-newline

# +2: [invalid-character-sub]
SUB = '''
--><---
'''  # bad char  sub should be only used as \x1A
