# The name is invalid, but we should not analyse this file
# Because its filename resembles an Emacs file lock ignored by default
# https://www.gnu.org/software/emacs/manual/html_node/elisp/File-Locks.html
# See https://github.com/pylint-dev/pylint/issues/367
