class Point:  # [multiple-constructor-doc]
    """Represents a point in the xy-coordinate plane.

    :param x: coordinate
    :param y: coordinate
    """

    def __init__(self, x, y):
        """Represents a point in the xy-coordinate plane.

        :param x: coordinate
        :param y: coordinate
        """
        self.x = x
        self.y = y
