r"""A raw docstring.
"""


def look_busy():
    xxxx = 1  # pylint: disable=duplicate-code
    yyyy = 2  # pylint: disable=duplicate-code
    zzzz = 3  # pylint: disable=duplicate-code
    wwww = 4  # pylint: disable=duplicate-code
    vvvv = xxxx + yyyy + zzzz + wwww  # pylint: disable=duplicate-code
    return vvvv  # pylint: disable=duplicate-code
