"""Check unknown or deleted option. """

# Standard disable with unknown value
# pylint: disable=C05048  # [unknown-option-value]
# Standard disable with deleted symbol
# pylint: disable=execfile-builtin  # [useless-option-value]
# Standard disable with symbol moved to extension
# pylint: disable=no-self-use  # [useless-option-value]
# Standard disable with deleted msgid
# pylint: disable=W1656  # [useless-option-value]
# Standard disable with msgid moved to extension
# pylint: disable=R0201  # [useless-option-value]
# disable-next with unknown value
# pylint: disable-next=R78948  # [unknown-option-value]
# disable-next with deleted symbol
# pylint: disable-next=deprecated-types-field  # [useless-option-value]
# disable-next with deleted msgid
# pylint: disable-next=W1634  # [useless-option-value]
# disable-next with symbol moved to extension
# pylint: disable-next=no-self-use  # [useless-option-value]
# disable-next with msgid moved to extension
# pylint: disable-next=R0201  # [useless-option-value]

# enable with unknown value
# pylint:enable=W04044  # [unknown-option-value]
# enable with deleted symbol
# pylint:enable=dict-values-not-iterating  # [useless-option-value]
# enable with symbol moved to extension
# pylint: enable=no-self-use  # [useless-option-value]
# enable with deleted msgid
# pylint:enable=W1622  # [useless-option-value]
# enable with msgid moved to extension
# pylint: enable=R0201  # [useless-option-value]

# Standard disable with deleted old name symbol of deleted message
# pylint: disable=no-space-after-operator  # [useless-option-value]
# Standard disable with deleted old name msgid of deleted message
# pylint: disable=C0323  # [useless-option-value]
